export interface FunctionTemplateHydration {
    /**
     * Id of function hydration
     * @readonly
     */
    id?: string | null;
    /**
     * Function definition
     * @readonly
     */
    function?: _Function;
    /**
     * Function spi configuration
     * @readonly
     */
    functionSpiConfiguration?: FunctionSpiConfiguration;
    /**
     * Function template automations
     * @readonly
     */
    automations?: Automation[];
    /**
     * Function methods
     * @readonly
     */
    functionMethods?: FunctionMethod[];
}
export interface _Function {
    /**
     * Function ID.
     * @readonly
     */
    id?: string | null;
    /**
     * Revision number, which increments by 1 each time the function is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the function.
     *
     * Ignored when creating a function.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the function was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the function was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /** The function's app extension ID. */
    functionExtensionId?: string | null;
    /** Function name. */
    functionName?: string | null;
    /**
     * Activation status
     * @readonly
     */
    activationStatus?: ActivationStatus;
    /** ID of the app that defines the function. */
    appId?: string | null;
    /** The function's app extension name. */
    functionExtensionName?: string | null;
    /** Function template extension id */
    functionTemplateExtensionId?: string | null;
    /** Form template extension id */
    formTemplateExtensionId?: string | null;
}
export declare enum ActivationStatus {
    /** Activation status is unknown. */
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** Function is activated. */
    ACTIVE = "ACTIVE",
    /** Function is deactivated. */
    INACTIVE = "INACTIVE",
    /** Function is saved but has never been activated. */
    DRAFT = "DRAFT"
}
/** SpiConfiguration is a spi configuration for a specific function. */
export interface FunctionSpiConfiguration {
    /**
     * SpiConfiguration ID.
     * @readonly
     */
    id?: string | null;
    /**
     * SpiConfiguration revision.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the SpiConfiguration was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the SpiConfiguration was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /** Function ID */
    functionId?: string | null;
    /** Function SPI configuration  dev center component payload. */
    configuration?: Record<string, any> | null;
}
export interface Automation extends AutomationOriginInfoOneOf {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
    /**
     * Automation ID.
     * @readonly
     */
    id?: string | null;
    /**
     * Revision number, which increments by 1 each time the automation is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the automation.
     *
     * Ignored when creating an automation.
     * @readonly
     */
    revision?: string | null;
    /**
     * Information about the creator of the automation.
     * @readonly
     */
    createdBy?: AuditInfo;
    /**
     * Date and time the automation was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * The entity that last updated the automation.
     * @readonly
     */
    updatedBy?: AuditInfo;
    /**
     * Date and time the automation was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /** Automation name that is displayed on the user's site. */
    name?: string;
    /** Automation description. */
    description?: string | null;
    /** Object that defines the automation's trigger, actions, and activation status. */
    configuration?: AutomationConfiguration;
    /** Defines how the automation was added to the site. */
    origin?: Origin;
    /** Automation settings. */
    settings?: AutomationSettings;
    /**
     * Draft info (optional - only if the automation is a draft)
     * @readonly
     */
    draftInfo?: DraftInfo;
    /** Namespace */
    namespace?: string | null;
    /** Extended Fields */
    extendedFields?: ExtendedFields;
}
/** @oneof */
export interface AutomationOriginInfoOneOf {
    /** Application info */
    applicationInfo?: ApplicationOrigin;
    /** Preinstalled info */
    preinstalledInfo?: PreinstalledOrigin;
}
export interface ActionSettings {
    /**
     * List of actions that cannot be deleted.
     * Default: Empty. All actions are deletable by default.
     */
    permanentActionIds?: string[];
    /**
     * List of actions that cannot be edited.
     * Default: Empty. All actions are editable by default.
     */
    readonlyActionIds?: string[];
    /** Whether the option to add a delay is disabled for the automation. */
    disableDelayAddition?: boolean;
    /** Whether the option to add a condition is disabled for the automation. */
    disableConditionAddition?: boolean;
}
export declare enum Domain {
    /** User domain (default). */
    USER = "USER",
    /** Wix domain. */
    WIX = "WIX"
}
export interface Enrichment {
    /** Enrichment input mappings. */
    inputMappings?: Record<string, any>[] | null;
}
export interface AuditInfo extends AuditInfoIdOneOf {
    /** User ID. */
    userId?: string;
    /** Application ID. */
    appId?: string;
}
/** @oneof */
export interface AuditInfoIdOneOf {
    /** User ID. */
    userId?: string;
    /** Application ID. */
    appId?: string;
}
/** Automation runtime configuration */
export interface AutomationConfiguration {
    /** Status of the automation on the site. */
    status?: Status;
    /** Automation trigger configuration. */
    trigger?: Trigger;
    /** List of IDs of root actions. Root actions are the first actions to run after the trigger. The actions in the list run in parallel. */
    rootActionIds?: string[];
    /**
     * Map of all actions that the automation may execute.
     * The key is the action ID, and the value is the action configuration.
     */
    actions?: Record<string, Action>;
}
export declare enum TimeUnit {
    UNKNOWN_TIME_UNIT = "UNKNOWN_TIME_UNIT",
    MINUTES = "MINUTES",
    HOURS = "HOURS",
    DAYS = "DAYS",
    WEEKS = "WEEKS",
    MONTHS = "MONTHS"
}
export interface Filter {
    /** Filter ID. */
    id?: string;
    /** Field key from the payload schema, for example "formId". */
    fieldKey?: string;
    /** Filter expression that evaluates to a boolean. */
    filterExpression?: string;
}
export interface FutureDateActivationOffset {
    /**
     * The offset value. The value is always taken as negative, so that the automation runs before the trigger date.
     * To create an offset that causes the automation to run after the trigger date, use a delay action.
     */
    preScheduledEventOffsetExpression?: string;
    /** Time unit for the scheduled event offset. */
    scheduledEventOffsetTimeUnit?: TimeUnit;
}
export interface RateLimit {
    /** Value expressing the maximum number of times the trigger can be activated. */
    maxActivationsExpression?: string;
    /** Duration of the rate limiting window in the selected time unit. If no value is set, the rate limit is permanent. */
    durationExpression?: string | null;
    /** Time unit for the rate limit duration. */
    durationTimeUnit?: TimeUnit;
    /** Unique identifier of each activation, by which rate limiter will count activations. */
    uniqueIdentifierExpression?: string | null;
}
export interface ConditionExpressionGroup {
    /** Expression group operator. */
    operator?: Operator;
    /** List of boolean expressions to be evaluated with the given operator. */
    booleanExpressions?: string[];
}
export declare enum Operator {
    UNKNOWN_OPERATOR = "UNKNOWN_OPERATOR",
    OR = "OR",
    AND = "AND"
}
export declare enum Type {
    /** Automation will be triggered according to the trigger configuration. */
    UNKNOWN_ACTION_TYPE = "UNKNOWN_ACTION_TYPE",
    /** App defined Action. */
    APP_DEFINED = "APP_DEFINED",
    /** Condition Action. */
    CONDITION = "CONDITION",
    /** Delay Action. */
    DELAY = "DELAY",
    /** RateLimit Action. */
    RATE_LIMIT = "RATE_LIMIT",
    /** Set Variables Action. */
    SET_VARIABLES = "SET_VARIABLES",
    /** Output Action. */
    OUTPUT = "OUTPUT"
}
export interface AppDefinedAction {
    /** ID of the app that defines the action. */
    appId?: string;
    /** Action key. */
    actionKey?: string;
    /** Action input mapping. */
    inputMapping?: Record<string, any> | null;
    /**
     * Array of conditions determining whether to skip the action in the automation flow.
     * The action will be skipped if any of the expression groups evaluate to `true`.
     * Actions following a skipped action will still run.
     */
    skipConditionOrExpressionGroups?: ConditionExpressionGroup[];
    /** List of IDs of actions to run in parallel once the action completes. */
    postActionIds?: string[];
    /** Optional output schema of the action. It will be used instead the action schema in case it's provided. */
    overrideOutputSchema?: Record<string, any> | null;
}
export interface ConditionAction {
    /** The condition evaluates to `true` if either of the expression groups evaluate to `true`. */
    orExpressionGroups?: ConditionExpressionGroup[];
    /** List of IDs of actions to run when the entire condition is evaluated to `true`. */
    truePostActionIds?: string[];
    /** List of IDs of actions to run when the entire condition is evaluated to `false`. */
    falsePostActionIds?: string[];
}
export interface DelayAction {
    /** Value expressing the amount of time to wait from a specific date or from the time the action is executed. */
    offsetExpression?: string | null;
    /** Time unit for delay offset. */
    offsetTimeUnit?: TimeUnit;
    /**
     * The action due date. If defined without an offset, the automation will wait until this date to execute the next step.
     * If an offset is defined, it's calculated from this date.
     * The date is expressed in the number of milliseconds since the Unix Epoch (1 January, 1970 UTC).
     */
    dueDateEpochExpression?: string | null;
    /** List of IDs of actions to run in parallel after the delay. */
    postActionIds?: string[];
}
export interface RateLimitAction {
    /** The maximum number of activations allowed for the action. */
    maxActivationsExpression?: string;
    /**
     * Duration of the rate limiting window, expressed in selected time unit.
     * If no value is set, then there is no time limit on the rate limiter.
     */
    rateLimitDurationExpression?: string | null;
    /** Time unit for the rate limit duration. */
    rateLimitDurationTimeUnit?: TimeUnit;
    /** Unique identifier of each activation by which rate limiter counts activations. */
    uniqueIdentifierExpression?: string | null;
    /** List of IDs of actions to run in parallel once the action completes. */
    postActionIds?: string[];
}
export interface SetVariablesAction {
    /**
     * output mapping
     * for example: {"someField": "{{10}}", "someOtherField": "{{multiply( var('account.points.balance') ;2 )}}" }
     */
    outputMapping?: Record<string, any> | null;
    /**
     * output json schema representation
     * could be string instead of Struct (and introduce some compression to minimize the size of it)
     */
    outputSchema?: Record<string, any> | null;
    /** List of IDs of actions to run in parallel after variable initialization. */
    postActionIds?: string[];
}
export interface OutputAction {
    /** Output action output mapping. */
    outputMapping?: Record<string, any> | null;
}
export declare enum Status {
    /** unused */
    UNKNOWN_STATUS = "UNKNOWN_STATUS",
    /** Automation will be triggered according to the trigger configuration */
    ACTIVE = "ACTIVE",
    /** Automation will not be triggered */
    INACTIVE = "INACTIVE"
}
export interface Trigger {
    /** ID of the app that defines the trigger. */
    appId?: string;
    /** Trigger key. */
    triggerKey?: string;
    /**
     * List of filters on schema fields.
     * In order for the automation to run, all filter expressions must evaluate to `true` for a given payload.
     */
    filters?: Filter[];
    /** Defines the time offset between the trigger date and when the automation runs. */
    scheduledEventOffset?: FutureDateActivationOffset;
    /** Limits the number of times an automation can be triggered. */
    rateLimit?: RateLimit;
    /**
     * An optional configuration, per automation, of a schema that is optionally offered by the trigger provider to affect the behavior of the trigger.
     * For example, a trigger provider may offer a schema that allows the user to configure the trigger to happen at a certain time of day,
     * He would define a schema with a field called "startDate" and using this parameter the user can define his preferred startDate, per automation.
     */
    automationConfigMapping?: Record<string, any> | null;
    /** Optional schema of the trigger. It will be used instead the trigger schema in case it's provided. */
    overrideSchema?: Record<string, any> | null;
}
export interface Action extends ActionInfoOneOf {
    /** Action defined by an app (via RPC, HTTP or Velo). */
    appDefinedInfo?: AppDefinedAction;
    /** Condition action. */
    conditionInfo?: ConditionAction;
    /** Delay action. */
    delayInfo?: DelayAction;
    /** Rate-limiting action. */
    rateLimitInfo?: RateLimitAction;
    /** Action ID. If not specified, a new ID is generated. */
    id?: string | null;
    /** Action type. */
    type?: Type;
    /**
     * Human-readable name to differentiate the action from other actions of the same type.
     * The name can contain only alphanumeric characters and underscores. If not provided, a namespace in the form `actionkey-indexOfAction` is
     * generated automatically.
     * If the action has output, the output will be available in the payload under this name.
     * If the user has multiple actions with the same appId and actionKey, previous action output will be overwritten.
     */
    namespace?: string | null;
}
/** @oneof */
export interface ActionInfoOneOf {
    /** Action defined by an app (via RPC, HTTP or Velo). */
    appDefinedInfo?: AppDefinedAction;
    /** Condition action. */
    conditionInfo?: ConditionAction;
    /** Delay action. */
    delayInfo?: DelayAction;
    /** Rate-limiting action. */
    rateLimitInfo?: RateLimitAction;
}
export declare enum Origin {
    /** Default value. This is unused. */
    UNKNOWN_ORIGIN = "UNKNOWN_ORIGIN",
    /** User created automation. */
    USER = "USER",
    /** Automation created by application (site specific). */
    APPLICATION = "APPLICATION",
    /** Preinstalled application automation. */
    PREINSTALLED = "PREINSTALLED",
    /** Automation created from a recipe. */
    RECIPE = "RECIPE"
}
export interface ApplicationOrigin {
    /** Application ID. */
    appId?: string;
}
export interface PreinstalledOrigin {
    /** ID of the app that defines the preinstalled automation. */
    appId?: string;
    /** Application component ID. */
    componentId?: string;
    /** Application component version. */
    componentVersion?: number;
    /**
     * Whether the automation is an override automation. If the user modifies the preinstalled automation installed on their site, a site-specific
     * automation is created that overrides the original one. If the user makes no modifications this boolean is set to `false` and the original
     * preinstalled automation is used.
     *
     * Default: `false`
     * @readonly
     */
    override?: boolean | null;
}
export interface AutomationSettings {
    /**
     * Whether the automation is hidden from users.
     * Default: `false`
     */
    hidden?: boolean;
    /**
     * Whether the automation is read-only.
     * Default: `false`
     */
    readonly?: boolean;
    /**
     * Whether the option to delete the automation from the site is disabled.
     * Default: `false`
     */
    disableDelete?: boolean;
    /**
     * Whether the option to change the automation status (from active to inactive and vice versa) is disabled.
     * Default: `false`
     */
    disableStatusChange?: boolean;
    /** Automation action settings. */
    actionSettings?: ActionSettings;
}
export interface DraftInfo {
    /**
     * Optional - automationId of the original automation.
     * @readonly
     */
    originalAutomationId?: string | null;
}
export interface Enrichments {
    /** Whether the studio site enrichment is wanted. */
    studioSite?: Enrichment;
}
export interface ExtendedFields {
    /**
     * Extended field data. Each key corresponds to the namespace of the app that created the extended fields.
     * The value of each key is structured according to the schema defined when the extended fields were configured.
     *
     * You can only access fields for which you have the appropriate permissions.
     *
     * Learn more about [extended fields](https://dev.wix.com/docs/rest/articles/getting-started/extended-fields).
     */
    namespaces?: Record<string, Record<string, any>>;
}
export interface FunctionMethod {
    /**
     * Function method ID.
     * @readonly
     */
    id?: string | null;
    /**
     * Function method revision.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the Function was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the Function was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /** Automation ID. */
    automationId?: string;
    /** Function ID. */
    functionId?: string;
    /** Method name */
    methodName?: string;
}
export interface HydrateFunctionTemplateRequest {
    /** App id where function template extension is created */
    appId: string;
    /** function extension id */
    functionTemplateExtensionId: string;
}
export interface HydrateFunctionTemplateResponse {
    /** Hydrated function template */
    functionTemplateHydration?: FunctionTemplateHydration;
}
export interface HydrateBlankFunctionTemplateRequest {
    /** App id where function extension is created */
    appId: string;
    /** function extension id */
    functionExtensionId: string;
}
export interface HydrateBlankFunctionTemplateResponse {
    /** Hydrated function template */
    functionTemplateHydration?: FunctionTemplateHydration;
}
interface _FunctionNonNullableFields {
    activationStatus: ActivationStatus;
}
interface ApplicationOriginNonNullableFields {
    appId: string;
}
interface PreinstalledOriginNonNullableFields {
    appId: string;
    componentId: string;
    componentVersion: number;
}
interface AuditInfoNonNullableFields {
    userId: string;
    appId: string;
}
interface FilterNonNullableFields {
    id: string;
    fieldKey: string;
    filterExpression: string;
}
interface FutureDateActivationOffsetNonNullableFields {
    preScheduledEventOffsetExpression: string;
    scheduledEventOffsetTimeUnit: TimeUnit;
}
interface RateLimitNonNullableFields {
    maxActivationsExpression: string;
    durationTimeUnit: TimeUnit;
}
interface TriggerNonNullableFields {
    appId: string;
    triggerKey: string;
    filters: FilterNonNullableFields[];
    scheduledEventOffset?: FutureDateActivationOffsetNonNullableFields;
    rateLimit?: RateLimitNonNullableFields;
}
interface AutomationConfigurationNonNullableFields {
    status: Status;
    trigger?: TriggerNonNullableFields;
    rootActionIds: string[];
}
interface ActionSettingsNonNullableFields {
    permanentActionIds: string[];
    readonlyActionIds: string[];
    disableDelayAddition: boolean;
    disableConditionAddition: boolean;
}
interface AutomationSettingsNonNullableFields {
    hidden: boolean;
    readonly: boolean;
    disableDelete: boolean;
    disableStatusChange: boolean;
    actionSettings?: ActionSettingsNonNullableFields;
    domain: Domain;
}
interface AutomationNonNullableFields {
    applicationInfo?: ApplicationOriginNonNullableFields;
    preinstalledInfo?: PreinstalledOriginNonNullableFields;
    createdBy?: AuditInfoNonNullableFields;
    updatedBy?: AuditInfoNonNullableFields;
    name: string;
    configuration?: AutomationConfigurationNonNullableFields;
    origin: Origin;
    settings?: AutomationSettingsNonNullableFields;
}
interface FunctionMethodNonNullableFields {
    automationId: string;
    functionId: string;
    methodName: string;
}
interface FunctionTemplateHydrationNonNullableFields {
    function?: _FunctionNonNullableFields;
    automations: AutomationNonNullableFields[];
    functionMethods: FunctionMethodNonNullableFields[];
}
export interface HydrateFunctionTemplateResponseNonNullableFields {
    functionTemplateHydration?: FunctionTemplateHydrationNonNullableFields;
}
export interface HydrateBlankFunctionTemplateResponseNonNullableFields {
    functionTemplateHydration?: FunctionTemplateHydrationNonNullableFields;
}
export {};
