import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixFunctionsTemplatesHydrationsV1FunctionTemplateHydrationsUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/functions/v1/template-hydrations',
                destPath: '/v1/function-template-hydrations',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/functions/v1/template-hydrations',
                destPath: '/v1/function-template-hydrations',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_functions_function-template-hydration';
/** Hydrating the function template extension with data from siteless meta site */
export function hydrateFunctionTemplate(payload) {
    function __hydrateFunctionTemplate({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function_template_hydration',
            method: 'POST',
            methodFqn: 'wix.functions.templates.hydrations.v1.FunctionTemplateHydrations.HydrateFunctionTemplate',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesHydrationsV1FunctionTemplateHydrationsUrl({
                protoPath: '/v1/function-template-hydrations/hydrate',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'functionTemplateHydration.function.createdDate' },
                        { path: 'functionTemplateHydration.function.updatedDate' },
                        {
                            path: 'functionTemplateHydration.functionSpiConfiguration.createdDate',
                        },
                        {
                            path: 'functionTemplateHydration.functionSpiConfiguration.updatedDate',
                        },
                        { path: 'functionTemplateHydration.automations.createdDate' },
                        { path: 'functionTemplateHydration.automations.updatedDate' },
                        {
                            path: 'functionTemplateHydration.automations.draftUpdatedDate',
                        },
                        { path: 'functionTemplateHydration.functionMethods.createdDate' },
                        { path: 'functionTemplateHydration.functionMethods.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __hydrateFunctionTemplate;
}
/**
 * Scratch version of the function extension
 * Generated automatically by the function extension id
 * Does not require any additional input from template
 */
export function hydrateBlankFunctionTemplate(payload) {
    function __hydrateBlankFunctionTemplate({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function_template_hydration',
            method: 'POST',
            methodFqn: 'wix.functions.templates.hydrations.v1.FunctionTemplateHydrations.HydrateBlankFunctionTemplate',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesHydrationsV1FunctionTemplateHydrationsUrl({
                protoPath: '/v1/function-template-hydrations/hydrate-blank',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'functionTemplateHydration.function.createdDate' },
                        { path: 'functionTemplateHydration.function.updatedDate' },
                        {
                            path: 'functionTemplateHydration.functionSpiConfiguration.createdDate',
                        },
                        {
                            path: 'functionTemplateHydration.functionSpiConfiguration.updatedDate',
                        },
                        { path: 'functionTemplateHydration.automations.createdDate' },
                        { path: 'functionTemplateHydration.automations.updatedDate' },
                        {
                            path: 'functionTemplateHydration.automations.draftUpdatedDate',
                        },
                        { path: 'functionTemplateHydration.functionMethods.createdDate' },
                        { path: 'functionTemplateHydration.functionMethods.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __hydrateBlankFunctionTemplate;
}
//# sourceMappingURL=functions-v1-function-template-hydration-function-template-hydration.http.js.map