import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixFunctionsV1FunctionTemplateHydration from './functions-v1-function-template-hydration-function-template-hydration.http.js';
export var ActivationStatus;
(function (ActivationStatus) {
    /** Activation status is unknown. */
    ActivationStatus["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
    /** Function is activated. */
    ActivationStatus["ACTIVE"] = "ACTIVE";
    /** Function is deactivated. */
    ActivationStatus["INACTIVE"] = "INACTIVE";
    /** Function is saved but has never been activated. */
    ActivationStatus["DRAFT"] = "DRAFT";
})(ActivationStatus || (ActivationStatus = {}));
export var Domain;
(function (Domain) {
    /** User domain (default). */
    Domain["USER"] = "USER";
    /** Wix domain. */
    Domain["WIX"] = "WIX";
})(Domain || (Domain = {}));
export var TimeUnit;
(function (TimeUnit) {
    TimeUnit["UNKNOWN_TIME_UNIT"] = "UNKNOWN_TIME_UNIT";
    TimeUnit["MINUTES"] = "MINUTES";
    TimeUnit["HOURS"] = "HOURS";
    TimeUnit["DAYS"] = "DAYS";
    TimeUnit["WEEKS"] = "WEEKS";
    TimeUnit["MONTHS"] = "MONTHS";
})(TimeUnit || (TimeUnit = {}));
export var Operator;
(function (Operator) {
    Operator["UNKNOWN_OPERATOR"] = "UNKNOWN_OPERATOR";
    Operator["OR"] = "OR";
    Operator["AND"] = "AND";
})(Operator || (Operator = {}));
export var Type;
(function (Type) {
    /** Automation will be triggered according to the trigger configuration. */
    Type["UNKNOWN_ACTION_TYPE"] = "UNKNOWN_ACTION_TYPE";
    /** App defined Action. */
    Type["APP_DEFINED"] = "APP_DEFINED";
    /** Condition Action. */
    Type["CONDITION"] = "CONDITION";
    /** Delay Action. */
    Type["DELAY"] = "DELAY";
    /** RateLimit Action. */
    Type["RATE_LIMIT"] = "RATE_LIMIT";
    /** Set Variables Action. */
    Type["SET_VARIABLES"] = "SET_VARIABLES";
    /** Output Action. */
    Type["OUTPUT"] = "OUTPUT";
})(Type || (Type = {}));
export var Status;
(function (Status) {
    /** unused */
    Status["UNKNOWN_STATUS"] = "UNKNOWN_STATUS";
    /** Automation will be triggered according to the trigger configuration */
    Status["ACTIVE"] = "ACTIVE";
    /** Automation will not be triggered */
    Status["INACTIVE"] = "INACTIVE";
})(Status || (Status = {}));
export var Origin;
(function (Origin) {
    /** Default value. This is unused. */
    Origin["UNKNOWN_ORIGIN"] = "UNKNOWN_ORIGIN";
    /** User created automation. */
    Origin["USER"] = "USER";
    /** Automation created by application (site specific). */
    Origin["APPLICATION"] = "APPLICATION";
    /** Preinstalled application automation. */
    Origin["PREINSTALLED"] = "PREINSTALLED";
    /** Automation created from a recipe. */
    Origin["RECIPE"] = "RECIPE";
})(Origin || (Origin = {}));
/**
 * Hydrating the function template extension with data from siteless meta site
 * @param appId - App id where function template extension is created
 * @public
 * @documentationMaturity preview
 * @requiredField appId
 * @requiredField options
 * @requiredField options.functionTemplateExtensionId
 * @permissionId FUNCTIONS.FUNCTION_TEMPLATE_HYDRATE
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @fqn wix.functions.templates.hydrations.v1.FunctionTemplateHydrations.HydrateFunctionTemplate
 */
export async function hydrateFunctionTemplate(appId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        appId: appId,
        functionTemplateExtensionId: options?.functionTemplateExtensionId,
    });
    const reqOpts = ambassadorWixFunctionsV1FunctionTemplateHydration.hydrateFunctionTemplate(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                appId: '$[0]',
                functionTemplateExtensionId: '$[1].functionTemplateExtensionId',
            },
            singleArgumentUnchanged: false,
        }, ['appId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Scratch version of the function extension
 * Generated automatically by the function extension id
 * Does not require any additional input from template
 * @param appId - App id where function extension is created
 * @public
 * @documentationMaturity preview
 * @requiredField appId
 * @requiredField options
 * @requiredField options.functionExtensionId
 * @permissionId FUNCTIONS.FUNCTION_TEMPLATE_HYDRATE
 * @permissionScope Manage Functions
 * @permissionScopeId SCOPE.DC-FUNCTIONS.MANAGE-FUNCTIONS
 * @applicableIdentity APP
 * @fqn wix.functions.templates.hydrations.v1.FunctionTemplateHydrations.HydrateBlankFunctionTemplate
 */
export async function hydrateBlankFunctionTemplate(appId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        appId: appId,
        functionExtensionId: options?.functionExtensionId,
    });
    const reqOpts = ambassadorWixFunctionsV1FunctionTemplateHydration.hydrateBlankFunctionTemplate(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                appId: '$[0]',
                functionExtensionId: '$[1].functionExtensionId',
            },
            singleArgumentUnchanged: false,
        }, ['appId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=functions-v1-function-template-hydration-function-template-hydration.universal.js.map