"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hydrateBlankFunctionTemplate = exports.hydrateFunctionTemplate = void 0;
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
function resolveWixFunctionsTemplatesHydrationsV1FunctionTemplateHydrationsUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/_api/functions/v1/template-hydrations',
                destPath: '/v1/function-template-hydrations',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/functions/v1/template-hydrations',
                destPath: '/v1/function-template-hydrations',
            },
        ],
    };
    return (0, rest_modules_1.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_functions_function-template-hydration';
/** Hydrating the function template extension with data from siteless meta site */
function hydrateFunctionTemplate(payload) {
    function __hydrateFunctionTemplate({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function_template_hydration',
            method: 'POST',
            methodFqn: 'wix.functions.templates.hydrations.v1.FunctionTemplateHydrations.HydrateFunctionTemplate',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesHydrationsV1FunctionTemplateHydrationsUrl({
                protoPath: '/v1/function-template-hydrations/hydrate',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'functionTemplateHydration.function.createdDate' },
                        { path: 'functionTemplateHydration.function.updatedDate' },
                        {
                            path: 'functionTemplateHydration.functionSpiConfiguration.createdDate',
                        },
                        {
                            path: 'functionTemplateHydration.functionSpiConfiguration.updatedDate',
                        },
                        { path: 'functionTemplateHydration.automations.createdDate' },
                        { path: 'functionTemplateHydration.automations.updatedDate' },
                        {
                            path: 'functionTemplateHydration.automations.draftUpdatedDate',
                        },
                        { path: 'functionTemplateHydration.functionMethods.createdDate' },
                        { path: 'functionTemplateHydration.functionMethods.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __hydrateFunctionTemplate;
}
exports.hydrateFunctionTemplate = hydrateFunctionTemplate;
/**
 * Scratch version of the function extension
 * Generated automatically by the function extension id
 * Does not require any additional input from template
 */
function hydrateBlankFunctionTemplate(payload) {
    function __hydrateBlankFunctionTemplate({ host }) {
        const metadata = {
            entityFqdn: 'wix.functions.v1.function_template_hydration',
            method: 'POST',
            methodFqn: 'wix.functions.templates.hydrations.v1.FunctionTemplateHydrations.HydrateBlankFunctionTemplate',
            packageName: PACKAGE_NAME,
            url: resolveWixFunctionsTemplatesHydrationsV1FunctionTemplateHydrationsUrl({
                protoPath: '/v1/function-template-hydrations/hydrate-blank',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'functionTemplateHydration.function.createdDate' },
                        { path: 'functionTemplateHydration.function.updatedDate' },
                        {
                            path: 'functionTemplateHydration.functionSpiConfiguration.createdDate',
                        },
                        {
                            path: 'functionTemplateHydration.functionSpiConfiguration.updatedDate',
                        },
                        { path: 'functionTemplateHydration.automations.createdDate' },
                        { path: 'functionTemplateHydration.automations.updatedDate' },
                        {
                            path: 'functionTemplateHydration.automations.draftUpdatedDate',
                        },
                        { path: 'functionTemplateHydration.functionMethods.createdDate' },
                        { path: 'functionTemplateHydration.functionMethods.updatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __hydrateBlankFunctionTemplate;
}
exports.hydrateBlankFunctionTemplate = hydrateBlankFunctionTemplate;
//# sourceMappingURL=functions-v1-function-template-hydration-function-template-hydration.http.js.map